pytilities.descriptors.dereferenceddescriptor — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »

# pytilities.descriptors.dereferenceddescriptor

`pytilities.descriptors.dereferenceddescriptor.` `DereferencedDescriptor`

  A descriptor that ‘dereferences’ another descriptor.

  The wrapped descriptor is supposed to describe another descriptor. The wrapper will pretend to be that more inner descriptor.

  For each call, wrapped_descriptor is getted with the given obj, and its return is used to perform the get, set, del on.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »